@@ -22,9 +22,10 @@
 #'
 #' @name scale_terrain
 #'
-#' @inheritParams ggplot2::scale_fill_viridis_b
-#'
 #' @inheritDotParams ggplot2::discrete_scale breaks:drop
+#' @inheritDotParams ggplot2::continuous_scale breaks:labels
+#' @inheritDotParams ggplot2::binned_scale breaks:limits nice.breaks
+#' @inheritParams scale_cross_blended
 #'
 #' @seealso
 #' [terra::plot()], [ggplot2::scale_fill_viridis_c()] and \pkg{ggplot2} docs on
@@ -72,12 +73,16 @@
 #'   geom_spatraster(data = factor, aes(fill = cats)) +
 #'   scale_fill_terrain_d(na.value = "gray10")
 #' }
-scale_fill_terrain_d <- function(..., alpha = 1, direction = 1) {
+scale_fill_terrain_d <- function(..., alpha = 1, direction = 1,
+                                 na.translate = FALSE,
+                                 drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "fill",
@@ -86,18 +91,24 @@ scale_fill_terrain_d <- function(..., alpha = 1, direction = 1) {
       alpha = alpha,
       direction = direction
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
 
 #' @export
 #' @rdname scale_terrain
-scale_colour_terrain_d <- function(..., alpha = 1, direction = 1) {
+scale_colour_terrain_d <- function(..., alpha = 1, direction = 1,
+                                   na.translate = FALSE,
+                                   drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "colour",
@@ -106,6 +117,8 @@ scale_colour_terrain_d <- function(..., alpha = 1, direction = 1) {
       alpha = alpha,
       direction = direction
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
@@ -113,14 +126,16 @@ scale_colour_terrain_d <- function(..., alpha = 1, direction = 1) {
 
 #' @export
 #' @rdname scale_terrain
-#' @inheritDotParams ggplot2::continuous_scale breaks:labels na.value
 scale_fill_terrain_c <- function(..., alpha = 1, direction = 1,
-                                 na.value = NA, guide = "colourbar") {
+                                 na.value = "transparent",
+                                 guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::continuous_scale(
     aesthetics = "fill",
@@ -138,12 +153,15 @@ scale_fill_terrain_c <- function(..., alpha = 1, direction = 1,
 #' @export
 #' @rdname scale_terrain
 scale_colour_terrain_c <- function(..., alpha = 1, direction = 1,
-                                   na.value = NA, guide = "colourbar") {
+                                   na.value = "transparent",
+                                   guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::continuous_scale(
     aesthetics = "colour",
@@ -161,14 +179,16 @@ scale_colour_terrain_c <- function(..., alpha = 1, direction = 1,
 
 #' @export
 #' @rdname scale_terrain
-#' @inheritDotParams ggplot2::binned_scale breaks:limits nice.breaks
 scale_fill_terrain_b <- function(..., alpha = 1, direction = 1,
-                                 na.value = NA, guide = "coloursteps") {
+                                 na.value = "transparent",
+                                 guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::binned_scale(
     aesthetics = "fill",
@@ -186,12 +206,15 @@ scale_fill_terrain_b <- function(..., alpha = 1, direction = 1,
 #' @export
 #' @rdname scale_terrain
 scale_colour_terrain_b <- function(..., alpha = 1, direction = 1,
-                                   na.value = NA, guide = "coloursteps") {
+                                   na.value = "transparent",
+                                   guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::binned_scale(
     aesthetics = "colour",
